@@ -69,7 +69,7 @@ sub create_zone {
 # SOA, Zfqdn:mname:rname:ser:ref:ret:exp:min:ttl:timestamp:lo
 #Ztesting.com:x2.nictool.com.:hostmaster.testing.com::16384:2048:1048576:2560:86400::
 
-    my $nameserver = $self->fully_qualify( $zone, $p{nameserver} || "a.ns" );
+    my $nameserver = $self->qualify( $zone, $p{nameserver} || "a.ns" );
 
     my $soa = $self->{special}{SOA};
 
@@ -155,21 +155,23 @@ sub create_zone_record {
 sub build_a {
     my ( $self, $p ) = @_;
 
-    my $r = $self->{special}{A};
-    $r .= $self->fully_qualify( $p->{zone}, $p->{name} ) . ":";
-    $r .= $p->{address} . ":";
-    $r .= $p->{ttl} || $prov->{config}{DNS}{ttl};
+    # +fqdn:ip:ttl:timestamp:lo
 
-    return $r;
+    return $self->{special}{A}
+     . $self->qualify( $p->{zone}, $p->{name} ) 
+     . ':' . $p->{address} 
+     . ':' . $p->{ttl} || $prov->{config}{DNS}{ttl}
+     . '::';
 }
 
 sub build_mx {
     my ( $self, $p ) = @_;
 
+    # @fqdn:ip:x:dist:ttl:timestamp:lo
     my $r = $self->{special}{MX};
-    $r .= $self->fully_qualify( $p->{zone}, $p->{name} ) . ":";
+    $r .= $self->qualify( $p->{zone}, $p->{name} ) . ":";
     $r .= ":";    # ip leave blank, defined with an A record
-    $r .= $self->fully_qualify( $p->{zone}, $p->{address} ) . ".:";
+    $r .= $self->qualify( $p->{zone}, $p->{address} ) . ".:";
     $r .= $p->{weight} . ":";
     $r .= $p->{ttl} || $prov->{config}{DNS}{ttl};
 
@@ -179,10 +181,11 @@ sub build_mx {
 sub build_ns {
     my ( $self, $p ) = @_;
 
+    # &fqdn:ip:x:ttl:timestamp:lo   (NS + A)
     my $r = $self->{special}{NS};
-    $r .= $self->fully_qualify( $p->{zone}, $p->{name} ) . ":";
+    $r .= $self->qualify( $p->{zone}, $p->{name} ) . ":";
     $r .= ":";    # ip leave blank, defined with an A record
-    $r .= $self->fully_qualify( $p->{zone}, $p->{address} ) . ".:";
+    $r .= $self->qualify( $p->{zone}, $p->{address} ) . ".:";
     $r .= $p->{ttl} || $prov->{config}{DNS}{ttl};
 
     return $r;
@@ -191,9 +194,10 @@ sub build_ns {
 sub build_cname {
     my ( $self, $p ) = @_;
 
+    # Cfqdn:p:ttl:timestamp:lo
     my $r = $self->{special}{CNAME};
-    $r .= $self->fully_qualify( $p->{zone}, $p->{name} ) . ":";
-    $r .= $self->fully_qualify( $p->{zone}, $p->{address} ) . ".:";
+    $r .= $self->qualify( $p->{zone}, $p->{name} ) . ":";
+    $r .= $self->qualify( $p->{zone}, $p->{address} ) . ".:";
     $r .= $p->{ttl} || $prov->{config}{DNS}{ttl};
 
     return $r;
@@ -202,8 +206,9 @@ sub build_cname {
 sub build_txt {
     my ( $self, $p ) = @_;
 
+    # 'fqdn:s:ttl:timestamp:lo
     my $r = $self->{special}{TXT};
-    $r .= $self->fully_qualify( $p->{zone}, $p->{name} ) . ":";
+    $r .= $self->qualify( $p->{zone}, $p->{name} ) . ":";
     $r .= $self->escape( $p->{address} ) . ":";
     $r .= $p->{ttl} || $prov->{config}{DNS}{ttl};
 
@@ -213,24 +218,28 @@ sub build_txt {
 sub build_ptr {
     my ( $self, $p ) = @_;
 
+    # ^fqdn:p:ttl:timestamp:lo
     my $r = $self->{special}{PTR};
 ## TODO
     # check that our zone matches NN.in-addr.arpa and/or a pattern
     # the can be automatically expanded as such
 
-    $r .= $self->fully_qualify( $p->{zone}, $p->{name} ) . ":";
+    $r .= $self->qualify( $p->{zone}, $p->{name} ) . ":";
     $r .= $p->{address} . ":";
     $r .= $p->{ttl} || $prov->{config}{DNS}{ttl};
 
     return $r;
 }
 
+sub build_soa {
+    my $self = shift;
+    # Zfqdn:mname:rname:ser:ref:ret:exp:min:ttl:timestamp:lo
+};
+
 sub build_srv {
     my ( $self, $p ) = @_;
 
-    #    $r .= $self->fully_qualify($p->{zone}, $p->{name}) . ":";
-    #    $r .= $self->escape($p->{address}) . ":";
-
+    # :fqdn:n:rdata:ttl:timestamp:lo (Generic record)
     my $priority = $p->{priority};
     my $weight   = $p->{weight};
     my $port     = $p->{port};
@@ -253,12 +262,12 @@ sub build_srv {
 
     my $target = "";
     my @chunks = split /\./,
-        $self->fully_qualify( $p->{zone}, $p->{address} );
+        $self->qualify( $p->{zone}, $p->{address} );
     foreach my $chunk (@chunks) {
         $target .= characterCount($chunk) . $chunk;
     }
 
-    my $service = $self->fully_qualify( $p->{zone}, $p->{name} );
+    my $service = $self->qualify( $p->{zone}, $p->{name} );
     $service = escape($service);
 
     my $r = ":";
@@ -272,6 +281,7 @@ sub build_srv {
 sub build_aaaa {
     my ( $self, $p ) = @_;
 
+# :fqdn:n:rdata:ttl:timestamp:lo (generic record format)
 # ffff:1234:5678:9abc:def0:1234:0:0
 # :example.com:28:\377\377\022\064\126\170\232\274\336\360\022\064\000\000\000\000
 
@@ -290,14 +300,14 @@ sub build_aaaa {
     $h = escapeHex( sprintf "%04s", $h );
 
     my $r = ':';
-    $r .= $self->fully_qualify( $p->{zone}, $p->{name} ) . ':';
+    $r .= $self->qualify( $p->{zone}, $p->{name} ) . ':';
     $r .= '28:' . "$a$b$c$d$e$f$g$h" . ':';
     $r .= $p->{ttl} || $prov->{config}{DNS}{ttl};
 
     return $r;
 }
 
-sub fully_qualify {
+sub qualify {
     my $self = shift;
     my ( $zone, $record ) = @_;
 
@@ -520,7 +530,7 @@ Provision::Unix::DNS::tinydns - Provision tinydns DNS entries
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
