@@ -7,7 +7,6 @@ use warnings;
 our $VERSION = '0.16';
 
 use English qw( -no_match_vars );
-use Carp;
 use Params::Validate qw( :all );
 
 use lib 'lib';
@@ -155,7 +154,7 @@ sub _create_dscl {
             mode  => '0755',
             debug => 0
             );
-        $util->chown( dir => $homedir, uid => $user, debug => $debug );
+        $util->chown( $homedir, uid => $user, gid=>$p_user->{gid}, debug => $debug );
     }
 
     return getpwnam($user);
@@ -171,7 +170,7 @@ sub _create_niutil {
 
     $util->syscmd( "$dirutil -create . /users/$user",
         debug => $debug,
-    ) or croak "failed to create user $user\n";
+    ) or die "failed to create user $user\n";
 
     $prov->progress( num => 6, desc => "configuring $user" );
 
@@ -202,7 +201,7 @@ sub _create_niutil {
 
     if ($homedir) {
         mkdir $homedir, 0755;
-        $util->chown( dir => $homedir, uid => $user, debug => $debug );
+        $util->chown( $homedir, uid => $user, gid=>$p_user->{gid}, debug => $debug );
     }
 
     return getpwnam($user);
@@ -243,6 +242,12 @@ sub destroy {
 
     $util->syscmd( $cmd, debug => 0 );
 
+    # flush the cache
+    my $cacheutil = $util->find_bin( "dscacheutil", debug => 0, fatal => 0 );
+    if ( -x $cacheutil ) {
+        $util->syscmd( "$cacheutil -flushcache", debug=>0, fatal=>0);
+    };
+
     return $self->exists($user)
         ? $prov->progress( num => 10, 'err' => 'failed' )
         : $prov->progress( num => 10, desc  => 'user destroyed' );
@@ -329,6 +334,12 @@ sub destroy_group {
         );
     }
 
+    # flush the cache
+    my $cacheutil = $util->find_bin( "dscacheutil", debug => 0, fatal => 0 );
+    if ( -x $cacheutil ) {
+        $util->syscmd( "$cacheutil -flushcache", debug=>0, fatal=>0);
+    };
+
     return getgrnam( $p{group} )
         ? $prov->progress( num => 10, 'err' => 'failed!' )
         : $prov->progress( num => 10, desc  => 'group deleted' );
@@ -366,7 +377,7 @@ Provision::Unix::User::Darwin - provision user accounts on Darwin systems
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
